@@ -14,4 +14,9 @@ try:
     from .dalle_mini.modeling_dalle_mini import DalleMini
 except Exception as e:
     logging.warning(repr(e))
-    logging.warning("WARNING! DALLE MINI NOT AVAILABLE.")
\ No newline at end of file
+    logging.warning("WARNING! DALLE MINI NOT AVAILABLE.")
+try:
+    from .glide.modeling_glide import Glide
+except Exception as e:
+    logging.warning(repr(e))
+    logging.warning("WARNING! GLIDE NOT AVAILABLE.")
\ No newline at end of file
